StreamEvent

Enum StreamEvent 

pub enum StreamEvent {
    Opened {
        id: StreamId,
    },
    Readable {
        id: StreamId,
    },
    Writable {
        id: StreamId,
    },
    Finished {
        id: StreamId,
    },
    Stopped {
        id: StreamId,
        error_code: ErrorCauseCode,
    },
    Available,
    BufferedAmountLow {
        id: StreamId,
    },
    BufferedAmountHigh {
        id: StreamId,
    },
}
Application events about streams

Variants



Opened

One or more new streams has been opened

Fields



Readable

A currently open stream has data or errors waiting to be read

Fields

id: StreamId

Which stream is now readable



Writable

A formerly write-blocked stream might be ready for a write or have been stopped

Only generated for streams that are currently open.

Fields

id: StreamId

Which stream is now writable



Finished

A finished stream has been fully acknowledged or stopped

Fields

id: StreamId

Which stream has been finished



Stopped

The peer asked us to stop sending on an outgoing stream

Fields

id: StreamId

Which stream has been stopped

error_code: ErrorCauseCode

Error code supplied by the peer



Available

At least one new stream of a certain directionality may be opened



BufferedAmountLow

The number of bytes of outgoing data buffered is lower than the threshold.

Fields

id: StreamId

Which stream is now readable



BufferedAmountHigh

The number of bytes of outgoing data buffered is higher than the threshold.

Fields

id: StreamId

Which stream is now readable